##  Overview
By visualizing the lifecycle phases of application fact sheets through a matrix report, you can identify outdated technologies, plan upgrades, and manage risks related to obsolete systems.
In this tutorial, you'll learn how to create a custom matrix report showing the lifecycle phases of application fact sheets along with their start dates.
To build a lifecycle matrix report, we'll use the [facet filter![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Finterfaces%2Flxr.ReportFacetsConfig.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://leanix.github.io/leanix-reporting/interfaces/lxr.ReportFacetsConfig.html") data fetching interface provided by the LeanIX Reporting Library. We'll use the [fixedFactSheetType![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Finterfaces%2Flxr.ReportFacetsConfig.html%23fixedFactSheetType "https://leanix.github.io/leanix-reporting/interfaces/lxr.ReportFacetsConfig.html#fixedFactSheetType") attribute to limit data to the Application fact sheet type.
To visually differentiate the various application lifecycle phases, we'll extract the color code associated with each phase from the [setup![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Finterfaces%2Flxr.ReportSetup.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://leanix.github.io/leanix-reporting/interfaces/lxr.ReportSetup.html") object of the workspace view model. This enables us to assign unique color codes to each phase, enhancing the visual clarity and interpretability of our application lifecycle matrix.
